@@ -22,7 +22,7 @@ setClass("guiWidgetsToolkittcltk",
 require(tcltk)
 oldClasses =c("tkwin", "tclVar", "tclObj")
 setClass("tcltkObject")
-sapply(oldClasses, function(i) {
+lapply(oldClasses, function(i) {
   setOldClass(i)
   setIs(i,"tcltkObject")
 })
@@ -347,11 +347,30 @@ setReplaceMethod(".enabled",
                    childComponents <- obj@e$childComponents
                    
                    if(!is.null(childComponents))
-                     sapply(childComponents,function(i) enabled(i) <- value)
+                     lapply(childComponents,function(i) enabled(i) <- value)
                             
                    return(obj)
                  })
 
+## editable or readonly
+## I want a editable<- method for gdf, gcombobox, glabel
+setMethod(".editable",
+          signature(toolkit="guiWidgetsToolkittcltk", obj="gWidgettcltk"),
+          function(obj, toolkit) {
+            widget <- getWidget(obj)            
+            as.character(tkcget(widget, "-state")) != "readonly"
+          })
+
+setReplaceMethod(".editable",
+                 signature(toolkit="guiWidgetsToolkittcltk", obj="gWidgettcltk", value="logical"),
+                 function(obj, toolkit, ..., value) {
+                   widget <- getWidget(obj)
+                   tkconfigure(widget, "state"=ifelse(value, "normal", "readonly"))
+                   return(obj)
+                 })
+
+
+
 ## focus
 focus_ttkwidget <- function(x, ...) as.logical(tcl(x, "instate", "focus"))
 focus_tkwidget <- function(x, ...) {
